@@ -71,4 +71,5 @@ class main_process():
         #os.remove(self.outFile)
 
 
-
+if __name__ == '__main__':
+    pass
